@@ -77,8 +77,8 @@ def monitored_channel(channel, monitored_channels):
 
     
 def play_sound(args):
-    filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
-    call([u"play", u"-q", filename])    
+    #filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
+    #call([u"play", u"-q", filename])    
 
 
 ##########################
@@ -111,8 +111,6 @@ def i_wrote_message(who):
     else:
         return False
 
-
-
 def construct_notification_command( title, body, urgency ):
     # notify-send -h string:bgcolor:#ff0000 -h string:fgcolor:#ff444 'Hello world!' 'This is an example notification.' --icon=dialog-information
     cmd = [u"notify-send"]
